@@ -613,14 +613,14 @@ def _elements_to_kwargs(elements,
 
     # if both vertex and face color are defined pick the one
     if 'face' in elements:
-        kwargs['face_colors'] = element_colors(elements['face'])
+        kwargs['face_colors'] = _element_colors(elements['face'])
     if 'vertex' in elements:
-        kwargs['vertex_colors'] = element_colors(elements['vertex'])
+        kwargs['vertex_colors'] = _element_colors(elements['vertex'])
 
     return kwargs
 
 
-def element_colors(element):
+def _element_colors(element):
     """
     Given an element, try to extract RGBA color from
     properties and return them as an (n,3|4) array.
@@ -645,7 +645,7 @@ def element_colors(element):
     return None
 
 
-def load_element_different(properties, data):
+def _load_element_different(properties, data):
     """
     Load elements which include lists of different lengths
     based on the element's property-definitions.
@@ -686,7 +686,7 @@ def load_element_different(properties, data):
     return squeeze
 
 
-def load_element_single(properties, data):
+def _load_element_single(properties, data):
     """
     Load element data with lists of a single length
     based on the element's property-definitions.
@@ -719,7 +719,8 @@ def load_element_single(properties, data):
             length = int(first[current])
             columns[name] = data[
                 :, current + 1:current + 1 + length].astype(dtype)
-            current += length
+            # offset by length of array plus one for each uint index
+            current += length + 1
         else:
             columns[name] = data[:, current:current + 1].astype(dt)
             current += 1
@@ -772,13 +773,13 @@ def _ply_ascii(elements, file_obj):
             # all rows have the same length and we only have at most one list
             # property where all entries have the same length. this means we can
             # use the quick numpy-based loading.
-            element_data = load_element_single(
+            element_data = _load_element_single(
                 values['properties'], data)
         else:
             # there are lists of differing lengths. we need to fall back to loading
             # the data by iterating all rows and checking for list-lengths. this is
             # slower than the variant above.
-            element_data = load_element_different(
+            element_data = _load_element_different(
                 values['properties'], data)
 
         elements[key]['data'] = element_data
