@@ -51,7 +51,8 @@ class RayMeshIntersector(object):
         """
         self.mesh = geometry
         self._scale_to_box = scale_to_box
-        self._cache = caching.Cache(id_function=self.mesh.crc)
+        self._cache = caching.Cache(
+            id_function=self.mesh.__hash__)
 
     @property
     def _scale(self):
@@ -235,7 +236,7 @@ class RayMeshIntersector(object):
             else:
                 break
 
-        # stack the deques into nice 1D numpy arrays
+        # stack the dequeues into nice 1D numpy arrays
         index_tri = np.hstack(result_triangle)
         index_ray = np.hstack(result_ray_idx)
 
